==> haskell-asn1-types-0.3.4-308.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO
key:                  asn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  84ac21745a63c08fdc23f398f50d1a1e
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-463kziEGjPc1qXS6uMhRJO
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-9RVtelOw0wXG6YiBQxfho6
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.4-309-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e
key:                  asn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  07f06536f81eb564b4f1474b6e275ec0
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-3PelmjEeZz36Y9JkroV62e
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-91uaLvWJDdFIwz6ObSsY6A
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
